Documentation
¶
Overview ¶
Package claudeagent implements the Claude Agent SDK harness. It spawns the claude-agent bridge subprocess and manages JSON-line I/O.
Index ¶
- func ValidateReadiness(cfg config.ClaudeCodeConfig) error
- type Harness
- func (h *Harness) Capabilities() adapter.HarnessCapabilities
- func (h *Harness) Name() string
- func (h *Harness) RunAction(ctx context.Context, req adapter.HarnessActionRequest) (adapter.HarnessActionResult, error)
- func (h *Harness) StartSession(ctx context.Context, opts adapter.SessionOpts) (_ adapter.AgentSession, err error)
- func (h *Harness) SupportsCompact() bool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ValidateReadiness ¶
func ValidateReadiness(cfg config.ClaudeCodeConfig) error
ValidateReadiness verifies that the claude-agent bridge can run with the configured runtime prerequisites.
Types ¶
type Harness ¶
type Harness struct {
// contains filtered or unexported fields
}
Harness implements adapter.AgentHarness for the Claude Agent SDK bridge.
func NewHarness ¶
func NewHarness(cfg config.ClaudeCodeConfig, workspaceRoot string) *Harness
NewHarness creates a new Claude Agent SDK harness.
func (*Harness) Capabilities ¶
func (h *Harness) Capabilities() adapter.HarnessCapabilities
Capabilities returns the harness capabilities.
func (*Harness) RunAction ¶
func (h *Harness) RunAction(ctx context.Context, req adapter.HarnessActionRequest) (adapter.HarnessActionResult, error)
func (*Harness) StartSession ¶
func (h *Harness) StartSession(ctx context.Context, opts adapter.SessionOpts) (_ adapter.AgentSession, err error)
StartSession spawns a new agent session with the given options.
func (*Harness) SupportsCompact ¶
Click to show internal directories.
Click to hide internal directories.