github

package
v0.0.1-alpha12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GithubAdapter

type GithubAdapter struct {
	// contains filtered or unexported fields
}

func New

func (*GithubAdapter) AddComment

func (a *GithubAdapter) AddComment(ctx context.Context, externalID string, body string) error

func (*GithubAdapter) Capabilities

func (a *GithubAdapter) Capabilities() adapter.AdapterCapabilities

func (*GithubAdapter) Fetch

func (a *GithubAdapter) Fetch(ctx context.Context, externalID string) (domain.Session, error)

func (*GithubAdapter) ListSelectable

func (a *GithubAdapter) ListSelectable(ctx context.Context, opts adapter.ListOpts) (*adapter.ListResult, error)

func (*GithubAdapter) Name

func (a *GithubAdapter) Name() string

func (*GithubAdapter) OnEvent

func (a *GithubAdapter) OnEvent(ctx context.Context, event domain.SystemEvent) error

func (*GithubAdapter) Resolve

func (*GithubAdapter) StartPRRefresh

func (a *GithubAdapter) StartPRRefresh(ctx context.Context, workspaceID string)

StartPRRefresh starts a background goroutine that periodically refreshes non-terminal GitHub pull requests from the API. It runs an immediate refresh on startup and then repeats every 120 seconds.

func (*GithubAdapter) UpdateState

func (a *GithubAdapter) UpdateState(ctx context.Context, externalID string, state domain.TrackerState) error

func (*GithubAdapter) Watch

Jump to